/*
    Парус 8 - Панели мониторинга - ТОиР - Прогнозирование технического состояния
    Закладка администрирования: дополнительная разметка и вёрстка клиентских элементов
*/

//---------------------
//Подключение библиотек
//---------------------

import React from "react"; //Классы React
import PropTypes from "prop-types"; //Контроль свойств компонента
import {
    Box,
    Stack,
    FormControl,
    InputLabel,
    Select,
    MenuItem,
    List,
    ListItem,
    ListItemButton,
    ListItemText,
    Card,
    CardContent,
    CardActions,
    Typography,
    Button
} from "@mui/material"; //Интерфейсные компоненты
import { APP_BAR_HEIGHT, TABS_HEIGHT, SCROLL_STYLES } from "./eqs_tech_cond_forecast_lyaout"; //Общие вспомогательные компоненты и вёрстка
import { P8PDataGrid, P8P_DATA_GRID_SIZE } from "../../components/p8p_data_grid"; //Таблица данных
import { P8P_DATA_GRID_CONFIG_PROPS } from "../../config_wrapper"; //Подключение компонентов к настройкам приложения

//---------
//Константы
//---------

//Высота списка выборок данных
const DS_SELECTOR_HEIGHT = "80px";

//Высота кнопки добавления технического объекта
const CM_ADD_BTN_HEIGHT = "46.5px";

//Структура элемента списка выборок данных оборудования
const EQUIP_DATA_SELECTION_LIST = PropTypes.shape({
    NRN: PropTypes.number.isRequired,
    SNAME: PropTypes.string.isRequired
});

//Структура элемента списка классов оборудования выборки данных
const EQUIP_DATA_SELECTION_CLASS_MACHINE_LIST = PropTypes.shape({
    NRN: PropTypes.number.isRequired,
    SCODE: PropTypes.string.isRequired,
    SNAME: PropTypes.string.isRequired
});

//Стили
const STYLES = {
    EQUIP_DS_LIST_FORM_CONTROL: { minWidth: "300px" },
    EQUIP_DSCM_LIST: {
        minHeight: `calc(100vh - ${APP_BAR_HEIGHT} - ${TABS_HEIGHT} - ${DS_SELECTOR_HEIGHT} - ${CM_ADD_BTN_HEIGHT})`,
        maxHeight: `calc(100vh - ${APP_BAR_HEIGHT} - ${TABS_HEIGHT} - ${DS_SELECTOR_HEIGHT} - ${CM_ADD_BTN_HEIGHT})`,
        overflowX: "hidden",
        overflowY: "auto",
        ...SCROLL_STYLES
    },
    EQUIP_DSCM_CARD: {
        minHeight: `calc(100vh - ${APP_BAR_HEIGHT} - ${TABS_HEIGHT} - ${DS_SELECTOR_HEIGHT})`,
        maxHeight: `calc(100vh - ${APP_BAR_HEIGHT} - ${TABS_HEIGHT} - ${DS_SELECTOR_HEIGHT})`,
        overflowY: "auto",
        ...SCROLL_STYLES
    },
    FL_ML_TABLE: {
        height: `200px`,
        ...SCROLL_STYLES
    }
};

//-----------
//Тело модуля
//-----------

//Список выборок данных оборудования
const EquipDataSelectionList = ({ list, value, onChange }) => {
    //При выборе элемента
    const handleChange = e => (onChange ? onChange(e.target.value) : null);

    //Генерация содержимого
    return (
        <FormControl variant="standard" sx={STYLES.EQUIP_DS_LIST_FORM_CONTROL}>
            <InputLabel id="equipDSlabel">Выборка данных оборудования</InputLabel>
            <Select labelId="equipDSlabel" id="equipDS" label="Выборка данных оборудования" value={value} onChange={handleChange}>
                {list.map((item, i) => (
                    <MenuItem key={i} value={item.NRN}>
                        {item.SNAME}
                    </MenuItem>
                ))}
            </Select>
        </FormControl>
    );
};

//Контроль свойств - Список выборок данных оборудования
EquipDataSelectionList.propTypes = {
    list: PropTypes.arrayOf(EQUIP_DATA_SELECTION_LIST).isRequired,
    value: PropTypes.number.isRequired,
    onChange: PropTypes.func
};

//Список классов оборудования выборки данных
const EquipDataSelectionClassMachineList = ({ list, value, onClick }) => {
    //При щелчке на элементе
    const handleClick = id => (onClick ? onClick(id) : null);

    //Генерация содержимого
    return (
        <List sx={STYLES.EQUIP_DSCM_LIST}>
            {list.map((item, i) => (
                <ListItem disablePadding key={i}>
                    <ListItemButton selected={value == item.NRN} onClick={() => handleClick(item.NRN)}>
                        <ListItemText primary={item.SCODE} secondary={item.SNAME} />
                    </ListItemButton>
                </ListItem>
            ))}
        </List>
    );
};

//Контроль свойств - Список классов оборудования выборки данных
EquipDataSelectionClassMachineList.propTypes = {
    list: PropTypes.arrayOf(EQUIP_DATA_SELECTION_CLASS_MACHINE_LIST).isRequired,
    value: PropTypes.number,
    onClick: PropTypes.func
};

//Карточка класса оборудования выборки данных
const EquipDataSelectionClassMachineCard = ({ filesList, modelsList }) => {
    //Генерация содержимого
    return (
        <Box p={2} sx={STYLES.EQUIP_DSCM_CARD}>
            <Stack spacing={2}>
                <Card>
                    <CardContent>
                        <Typography variant="h5" component="div">
                            Наименование технического объекта
                        </Typography>
                        <Typography sx={{ mb: 1.5 }} color="text.secondary">
                            Состояние: готов к ...
                        </Typography>
                        <Typography variant="body2">фывафывафва</Typography>
                    </CardContent>
                    <CardActions>
                        <Button size="large">Сформировать</Button>
                        <Button size="large">Передать данные</Button>
                        <Button size="large">Обучить модель</Button>
                    </CardActions>
                </Card>
                <Card>
                    <CardContent>
                        <Typography variant="h6" component="div">
                            Файлы данных
                        </Typography>
                        <P8PDataGrid
                            {...{ ...P8P_DATA_GRID_CONFIG_PROPS }}
                            containerComponentProps={{
                                sx: STYLES.FL_ML_TABLE,
                                elevation: 0
                            }}
                            columnsDef={filesList.columnsDef}
                            rows={filesList.rows}
                            size={P8P_DATA_GRID_SIZE.SMALL}
                            morePages={false}
                            fixedHeader={true}
                            reloading={false}
                        />
                    </CardContent>
                </Card>
                <Card>
                    <CardContent>
                        <Typography variant="h6" component="div">
                            Модели
                        </Typography>
                        <P8PDataGrid
                            {...{ ...P8P_DATA_GRID_CONFIG_PROPS }}
                            containerComponentProps={{
                                sx: STYLES.FL_ML_TABLE,
                                elevation: 0
                            }}
                            columnsDef={modelsList.columnsDef}
                            rows={modelsList.rows}
                            size={P8P_DATA_GRID_SIZE.SMALL}
                            morePages={false}
                            fixedHeader={true}
                            reloading={false}
                        />
                    </CardContent>
                </Card>
            </Stack>
        </Box>
    );
};

//----------------
//Интерфейс модуля
//----------------

export { EquipDataSelectionList, EquipDataSelectionClassMachineList, EquipDataSelectionClassMachineCard };
